==> mybody_api_client-0.4.1.tar.gz: mybody_api_client-0.4.1/mybody_api_client/routes/admin/meals/reports/products/__init__.py <==
#
# (c) 2024, Yegor Yakubovich, yegoryakubovich.com, personal@yegoryakybovich.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from mybody_api_client.utils import BaseRoute, RequestTypes


class AdminMealReportProductRoute(BaseRoute):
    prefix = '/products'

    async def create(
            self,
            meal_report_id: int,
            product_id: int,
            value: int,
    ):
        return await self.request(
            type_=RequestTypes.POST,
            prefix='/create',
            parameters={
                'meal_report_id': meal_report_id,
                'product_id': product_id,
                'value': value,
            },
            response_key='id',
        )

    async def delete(self, id_: int):
        return await self.request(
            type_=RequestTypes.POST,
            prefix='/delete',
            parameters={
                'id': id_,
            },
        )

    async def get_list(self, meal_report_id: int):
        return await self.request(
            type_=RequestTypes.GET,
            prefix='/list/get',
            parameters={
                'meal_report_id': meal_report_id,
            },
            response_key='meal_report_products',
        )

==> mybody_api_client-0.5.21.tar.gz: mybody_api_client-0.5.21/mybody_api_client/routes/admin/meals/reports/products/__init__.py <==
#
# (c) 2024, Yegor Yakubovich, yegoryakubovich.com, personal@yegoryakybovich.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from mybody_api_client.utils import BaseRoute, RequestTypes


class AdminMealReportProductRoute(BaseRoute):
    _prefix = '/products'

    async def create(
            self,
            meal_report_id: int,
            product_id: int,
            value: int,
    ):
        return await self._request(
            type_=RequestTypes.POST,
            prefix='/create',
            parameters={
                'meal_report_id': meal_report_id,
                'product_id': product_id,
                'value': value,
            },
            response_key='id',
        )

    async def delete(self, id_: int):
        return await self._request(
            type_=RequestTypes.POST,
            prefix='/delete',
            parameters={
                'id': id_,
            },
        )

    async def get_list(self, meal_report_id: int):
        return await self._request(
            type_=RequestTypes.GET,
            prefix='/list/get',
            parameters={
                'meal_report_id': meal_report_id,
            },
            response_key='meal_report_products',
        )
